hmLoadTopic({
hmKeywords:"",
hmTitle:"Table Compare File Format Settings",
hmDescription:"Specify the file format to be used when reading the left and\/or right files.  The default selection is Detected, which means the file format will be selected based on file...",
hmPrevLink:"sessiontablespecs.html",
hmNextLink:"sessiontablesheets.html",
hmParentLink:"sessiontable.html",
hmBreadCrumbs:"<a href=\"settings_reference.html\">Settings Reference<\/a> &gt; <a href=\"session_settings.html\">Session Settings<\/a> &gt; <a href=\"sessiontable.html\">Table Compare<\/a>",
hmTitlePath:"Settings Reference > Session Settings > Table Compare > Format",
hmHeader:"<h1 class=\"p_Heading1\"><span class=\"f_Heading1\">Table Compare File Format Settings<\/span><\/h1>\n\r",
hmBody:"<p class=\"p_Normal\">Specify the file format to be used when reading the left and\/or right files.  The default selection is Detected, which means the file format will be selected based on file masks.<\/p>\n\r<p class=\"p_Normal\"><span class=\"f_Command\">Encoding overrides<\/span> allow this session to override the character encoding to be used for each file, normally controlled by the selected file format.  The default is None, which means the file format\'s encoding choice will be used.<\/p>\n\r"
})
